@@ -11,9 +11,8 @@ no memleaks found on 110425
 */
 
 extern char *HYDRA_EXIT;
-char *buf;
 
-int32_t start_rsh(int32_t s, char *ip, int32_t port, unsigned char options, char *miscptr, FILE * fp) {
+int32_t start_rsh(int32_t s, char *ip, int32_t port, unsigned char options, char *miscptr, FILE *fp) {
   char *empty = "";
   char *login, buffer[300] = "", buffer2[100], *bptr = buffer2;
   int32_t ret;
@@ -40,8 +39,8 @@ int32_t start_rsh(int32_t s, char *ip, int32_t port, unsigned char options, char
   if ((ret = hydra_recv(s, buffer, sizeof(buffer) - 1)) > 0)
     buffer[ret] = 0;
   else /* 0x00 is sent but hydra_recv transformed it */
-    if ((ret = hydra_recv(s, buffer, sizeof(buffer) - 1)) > 0)
-       buffer[ret] = 0;
+      if ((ret = hydra_recv(s, buffer, sizeof(buffer) - 1)) > 0)
+    buffer[ret] = 0;
 #ifdef HAVE_PCRE
   if (ret > 0 && (!hydra_string_match(buffer, "\\s(failure|incorrect|denied)"))) {
 #else
@@ -58,7 +57,7 @@ int32_t start_rsh(int32_t s, char *ip, int32_t port, unsigned char options, char
   return 1;
 }
 
-void service_rsh(char *ip, int32_t sp, unsigned char options, char *miscptr, FILE * fp, int32_t port, char *hostname) {
+void service_rsh(char *ip, int32_t sp, unsigned char options, char *miscptr, FILE *fp, int32_t port, char *hostname) {
   int32_t run = 1, next_run = 1, sock = -1;
   int32_t myport = PORT_RSH, mysslport = PORT_RSH_SSL;
 
@@ -69,34 +68,34 @@ void service_rsh(char *ip, int32_t sp, unsigned char options, char *miscptr, FIL
   while (1) {
     next_run = 0;
     switch (run) {
-    case 1:                    /* connect and service init function */
-      {
-        hydra_set_srcport(1023);
-        if (sock >= 0)
-          sock = hydra_disconnect(sock);
-//        usleepn(275);
-        if ((options & OPTION_SSL) == 0) {
-          if (port != 0)
-            myport = port;
-          sock = hydra_connect_tcp(ip, myport);
-          port = myport;
-        } else {
-          if (port != 0)
-            mysslport = port;
-          sock = hydra_connect_ssl(ip, mysslport, hostname);
-          port = mysslport;
-        }
-        if (sock < 0) {
-          hydra_report(stderr, "[ERROR] Child with pid %d terminating, can not connect\n", (int32_t) getpid());
-          hydra_child_exit(1);
-        }
-        next_run = 2;
-        break;
+    case 1: /* connect and service init function */
+    {
+      hydra_set_srcport(1023);
+      if (sock >= 0)
+        sock = hydra_disconnect(sock);
+      //        usleepn(275);
+      if ((options & OPTION_SSL) == 0) {
+        if (port != 0)
+          myport = port;
+        sock = hydra_connect_tcp(ip, myport);
+        port = myport;
+      } else {
+        if (port != 0)
+          mysslport = port;
+        sock = hydra_connect_ssl(ip, mysslport, hostname);
+        port = mysslport;
       }
-    case 2:                    /* run the cracking function */
+      if (sock < 0) {
+        hydra_report(stderr, "[ERROR] Child with pid %d terminating, can not connect\n", (int32_t)getpid());
+        hydra_child_exit(1);
+      }
+      next_run = 2;
+      break;
+    }
+    case 2: /* run the cracking function */
       next_run = start_rsh(sock, ip, port, options, miscptr, fp);
       break;
-    case 3:                    /* clean exit */
+    case 3: /* clean exit */
       if (sock >= 0)
         sock = hydra_disconnect(sock);
       hydra_child_exit(0);
@@ -109,13 +108,13 @@ void service_rsh(char *ip, int32_t sp, unsigned char options, char *miscptr, FIL
   }
 }
 
-int32_t service_rsh_init(char *ip, int32_t sp, unsigned char options, char *miscptr, FILE * fp, int32_t port, char *hostname) {
+int32_t service_rsh_init(char *ip, int32_t sp, unsigned char options, char *miscptr, FILE *fp, int32_t port, char *hostname) {
   // called before the childrens are forked off, so this is the function
   // which should be filled if initial connections and service setup has to be
   // performed once only.
   //
   // fill if needed.
-  // 
+  //
   // return codes:
   //   0 all OK
   //   -1  error, hydra will exit, so print a good error message here
